# grascii-gui

[![PyPI - Version](https://img.shields.io/pypi/v/grascii-gui.svg)](https://pypi.org/project/grascii-gui)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/grascii-gui.svg)](https://pypi.org/project/grascii-gui)

-----

**Table of Contents**

- [About](#about)
- [Installation](#installation)
- [Usage](#usage)
- [License](#license)

## About

`grascii-gui` is a graphical interface for Grascii Search provided by
[`grascii`](https://github.com/grascii/grascii).

## Installation

```console
pip install grascii-gui
```

## Usage

```console
grascii-gui
```

## License

`grascii-gui` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
